BETACODE_MAP = {
    # No marks
    'a':       '\u03b1',
    'b':       '\u03b2',
    'g':       '\u03b3',
    'd':       '\u03b4',
    'e':       '\u03b5',
    'z':       '\u03b6',
    'h':       '\u03b7',
    'q':       '\u03b8',
    'i':       '\u03b9',
    'k':       '\u03ba',
    'l':       '\u03bb',
    'm':       '\u03bc',
    'n':       '\u03bd',
    'c':       '\u03be',
    'o':       '\u03bf',
    'p':       '\u03c0',
    'r':       '\u03c1',
    's':       '\u03c3',
    's1':      '\u03c3',
    's2':      '\u03c2',
    's3':      '\u03f2',
    't':       '\u03c4',
    'u':       '\u03c5',
    'f':       '\u03c6',
    'x':       '\u03c7',
    'y':       '\u03c8',
    'w':       '\u03c9',
    '*a':      '\u0391',
    '*b':      '\u0392',
    '*g':      '\u0393',
    '*d':      '\u0394',
    '*e':      '\u0395',
    '*z':      '\u0396',
    '*h':      '\u0397',
    '*q':      '\u0398',
    '*i':      '\u0399',
    '*k':      '\u039a',
    '*l':      '\u039b',
    '*m':      '\u039c',
    '*n':      '\u039d',
    '*c':      '\u039e',
    '*o':      '\u039f',
    '*p':      '\u03a0',
    '*r':      '\u03a1',
    '*s':      '\u03a3',
    '*s3':     '\u03f9',
    '*t':      '\u03a4',
    '*u':      '\u03a5',
    '*f':      '\u03a6',
    '*x':      '\u03a7',
    '*y':      '\u03a8',
    '*w':      '\u03a9',

    # Smooth breathing
    'a)':      '\u1f00',
    'e)':      '\u1f10',
    'h)':      '\u1f20',
    'i)':      '\u1f30',
    'o)':      '\u1f40',
    'u)':      '\u1f50',
    'w)':      '\u1f60',
    'r)':      '\u1fe4',
    '*)a':     '\u1f08',
    '*)e':     '\u1f18',
    '*)h':     '\u1f28',
    '*)i':     '\u1f38',
    '*)o':     '\u1f48',
    '*)w':     '\u1f68',

    # Rough breathing
    'a(':      '\u1f01',
    'e(':      '\u1f11',
    'h(':      '\u1f21',
    'i(':      '\u1f31',
    'o(':      '\u1f41',
    'u(':      '\u1f51',
    'w(':      '\u1f61',
    'r(':      '\u1fe5',
    '*(a':     '\u1f09',
    '*(e':     '\u1f19',
    '*(h':     '\u1f29',
    '*(i':     '\u1f39',
    '*(o':     '\u1f49',
    '*(u':     '\u1f59',
    '*(w':     '\u1f69',
    '*(r':     '\u1fec',

    # Acute accent and grave accent
    'a\\':     '\u1f70',
    'a/':      '\u1f71',
    'e\\':     '\u1f72',
    'e/':      '\u1f73',
    'h\\':     '\u1f74',
    'h/':      '\u1f75',
    'i\\':     '\u1f76',
    'i/':      '\u1f77',
    'o\\':     '\u1f78',
    'o/':      '\u1f79',
    'u\\':     '\u1f7a',
    'u/':      '\u1f7b',
    'w\\':     '\u1f7c',
    'w/':      '\u1f7d',
    '*\\a':    '\u1fba',
    '*/a':     '\u1fbb',
    '*\\e':    '\u1fce',
    '*/e':     '\u1fc9',
    '*\\h':    '\u1fca',
    '*/h':     '\u1fcb',
    '*\\i':    '\u1fda',
    '*/i':     '\u1fdb',
    '*\\o':    '\u1ff8',
    '*/o':     '\u1ff9',
    '*\\u':    '\u1fea',
    '*/u':     '\u1feb',
    '*\\w':    '\u1ffa',
    '*/w':     '\u1ffb',

    # Smooth breathing and acute accent
    'a)/':     '\u1f04',
    'e)/':     '\u1f14',
    'h)/':     '\u1f24',
    'i)/':     '\u1f34',
    'o)/':     '\u1f44',
    'u)/':     '\u1f54',
    'w)/':     '\u1f64',
    '*)/a':    '\u1f0c',
    '*)/e':    '\u1f1c',
    '*)/h':    '\u1f2c',
    '*)/i':    '\u1f3c',
    '*)/o':    '\u1f4c',
    '*)/u':    '\u1f5c',
    '*)/w':    '\u1f6c',

    # Smooth breathing and grave accent
    'a)\\':    '\u1f02',
    'e)\\':    '\u1f12',
    'h)\\':    '\u1f22',
    'i)\\':    '\u1f32',
    'o)\\':    '\u1f42',
    'u)\\':    '\u1f52',
    'w)\\':    '\u1f62',
    '*)\\a':   '\u1f0a',
    '*)\\e':   '\u1f1a',
    '*)\\h':   '\u1f2a',
    '*)\\i':   '\u1f3a',
    '*)\\o':   '\u1f4a',
    '*)\\u':   '\u1f5a',
    '*)\\w':   '\u1f6a',

    # Rough breathing and acute accent
    'a(/':     '\u1f05',
    'e(/':     '\u1f15',
    'h(/':     '\u1f25',
    'i(/':     '\u1f35',
    'o(/':     '\u1f45',
    'u(/':     '\u1f55',
    'w(/':     '\u1f65',
    '*(/a':    '\u1f0d',
    '*(/e':    '\u1f1d',
    '*(/h':    '\u1f2d',
    '*(/i':    '\u1f3d',
    '*(/o':    '\u1f4d',
    '*(/u':    '\u1f5d',
    '*(/w':    '\u1f6d',

    # Rough breathing and grave accent
    'a(\\':    '\u1f03',
    'e(\\':    '\u1f13',
    'h(\\':    '\u1f23',
    'i(\\':    '\u1f33',
    'o(\\':    '\u1f43',
    'u(\\':    '\u1f53',
    'w(\\':    '\u1f63',
    '*(\\a':   '\u1f0b',
    '*(\\e':   '\u1f1b',
    '*(\\h':   '\u1f2b',
    '*(\\i':   '\u1f3b',
    '*(\\o':   '\u1f4b',
    '*(\\u':   '\u1f5b',
    '*(\\w':   '\u1f6b',

    # Perispomeni
    'a=':     '\u1fb6',
    'h=':     '\u1fc6',
    'i=':     '\u1fd6',
    'u=':     '\u1fe6',
    'w=':     '\u1ff6',

    # Smooth breathing and perispomeni
    'a)=':    '\u1f06',
    'h)=':    '\u1f26',
    'i)=':    '\u1f36',
    'u)=':    '\u1f56',
    'w)=':    '\u1f66',
    '*)=a':   '\u1f0e',
    '*)=h':   '\u1f2e',
    '*)=i':   '\u1f3e',
    '*)=w':   '\u1f6e',

    # Rough breathing and perispomeni
    'a(=':    '\u1f07',
    'h(=':    '\u1f27',
    'i(=':    '\u1f37',
    'u(=':    '\u1f57',
    'w(=':    '\u1f67',
    '*(=a':   '\u1f0f',
    '*(=h':   '\u1f2f',
    '*(=i':   '\u1f3f',
    '*(=u':   '\u1f5f',
    '*(=w':   '\u1f6f',

    # Perispomeni and ypogegrammeni
    'a=|':    '\u1fb7',
    'h=|':    '\u1fc7',
    'w=|':    '\u1ff7',

    # Ypogegrammeni
    'a|':     '\u1fb3',
    'h|':     '\u1fc3',
    'w|':     '\u1ff3',
    '*a|':    '\u1fbc',
    '*h|':    '\u1fcc',
    '*w|':    '\u1ffc',

    # Acute accent and ypogegrammeni
    'a/|':    '\u1fb4',
    'h/|':    '\u1fc4',
    'w/|':    '\u1ff4',

    # Smooth breathing and ypogegrammeni
    'a)|':    '\u1f80',
    'h)|':    '\u1f90',
    'w)|':    '\u1fa0',
    '*)a|':   '\u1f88',
    '*)h|':   '\u1f98',
    '*)w|':   '\u1fa8',

    # Rough breathing and ypogegrammeni
    'a(|':    '\u1f81',
    'h(|':    '\u1f91',
    'w(|':    '\u1fa1',
    '*(a|':   '\u1f89',
    '*(h|':   '\u1f99',
    '*(w|':   '\u1fa9',

    # Smooth breathing, acute accent, and ypogegrammeni
    'a)\|':   '\u1f82',
    'h)\|':   '\u1f92',
    'w)\|':   '\u1fa2',
    '*)\\a|': '\u1f8a',
    '*)\h|':  '\u1f9a',
    '*)\w|':  '\u1faa',

    # Rough breathing, grave accent, and ypogegrammeni
    'a(\|':   '\u1f83',
    'h)\|':   '\u1f93',
    'w)\|':   '\u1fa3',
    '*(\\a|': '\u1f8b',
    '*)\h|':  '\u1f9b',
    '*)\w|':  '\u1fab',

    # Smooth breathing, accute accent, and ypogegrammeni
    'a)/|':   '\u1f84',
    'h)/|':   '\u1f94',
    'w)/|':   '\u1fa4',
    '*)/a|':  '\u1f8c',
    '*)/h|':  '\u1f9c',
    '*)/w|':  '\u1fac',

    # Rough breating, acute accent, and ypogegrammeni
    'a(/|':   '\u1f85',
    'h(/|':   '\u1f95',
    'w(/|':   '\u1fa5',
    '*(/a|':  '\u1f8d',
    '*(/h|':  '\u1f9d',
    '*(/w|':  '\u1fad',

    # Smooth breathing, ypogegrammeni, and perispomeni
    'a)=|':   '\u1f86',
    'h)=|':   '\u1f96',
    'w)=|':   '\u1fa6',
    '*)=a|':  '\u1f8e',
    '*)=h|':  '\u1f9e',
    '*)=w|':  '\u1fae',

    # Rough breathing, ypogegrammeni, and perispomeni
    'a(=|':   '\u1f87',
    'h(=|':   '\u1f97',
    'w(=|':   '\u1fa7',
    '*(=a|':  '\u1f8f',
    '*(=h|':  '\u1f9f',
    '*(=w|':  '\u1faf',

    # Diaeresis
    'i+':     '\u03ca',
    '*+i':    '\u03aa',
    'i\\+':   '\u1fd2',
    'i/+':    '\u1fd3',
    'i+/':    '\u1fd3',
    'i=+':    '\u1fd7',
    'u+':     '\u03cb',
    '*+u':    '\u03ab',
    'u\\+':   '\u1fe2',
    'u/+':    '\u1fe3',
    'u=+':    '\u1fe7',

    # Macron
    'a&':     '\u1fb0',
    'i&':     '\u1fd0',
    'u&':     '\u1fe0',

    # Breve
    'a\'':    '\u1fb1',
    'i\'':    '\u1fd1',
    'u\'':    '\u1fe1',

    # Basic punctuation
    ':':      '\u00b7',
    '\'':     '\u2019',
    '-':      '\u2010',
    '_':      '\u2014'
}
